@@ -1,6 +1,7 @@
 import json
 from tornado import web
 from jupyterhub.apihandlers.base import APIHandler
+from jupyterhub.apihandlers import default_handlers
 
 from .orm import UserInfo
 
@@ -15,7 +16,6 @@ class CognitoAPIHandler(APIHandler):
         # ensure we have permission to identify ourselves
         # all tokens can do this on this endpoint
         model = get_model(userinfo)
-        print(model)
         self.write(json.dumps(model))
 
     def userinfo_model(self, userinfo):
@@ -31,3 +31,6 @@ class CognitoAPIHandler(APIHandler):
             'refresh_token': user.refresh_token
         }
         return model
+
+
+default_handlers.append((r"/api/user/cognito-token", CognitoAPIHandler))
